about summary refs log tree commit diff
path: root/Src/builtin.c
diff options
context:
space:
mode:
Diffstat (limited to 'Src/builtin.c')
-rw-r--r--Src/builtin.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Src/builtin.c b/Src/builtin.c
index b0d4eb7f7..f0c490119 100644
--- a/Src/builtin.c
+++ b/Src/builtin.c
@@ -2492,7 +2492,7 @@ typeset_single(char *cname, char *pname, Param pm, UNUSED(int func),
 	    }
 	}
 	if (isset(POSIXBUILTINS))
-	    pm->node.flags |= PM_DECLAREDNULL;
+	    pm->node.flags |= PM_DEFAULTED;
     } else {
 	if (idigit(*pname))
 	    zerrnam(cname, "not an identifier: %s", pname);
@@ -2892,7 +2892,7 @@ bin_typeset(char *name, char **argv, LinkList assigns, Options ops, int func)
 	 * Don't attempt to set it yet, it's too early
 	 * to be exported properly.
 	 *
 	 * This may create the array with PM_DECLAREDNULL.
 	 */
 	asg2.name = asg->name;
 	asg2.flags = 0;
@@ -2936,7 +2936,7 @@ bin_typeset(char *name, char **argv, LinkList assigns, Options ops, int func)
 	    assignaparam(asg->name, zlinklist2array(asg->value.array, 1), flags);
 	} else if (asg0.value.scalar || oldval) {
 	    /* We have to undo what we did wrong with asg2 */
-	    apm->node.flags &= ~PM_DECLAREDNULL;
+	    apm->node.flags &= ~PM_DEFAULTED;
 	    if (oldval)
 		assignsparam(asg0.name, oldval, 0);
 	}
@@ -2892,7 +2892,7 @@ bin_typeset(char *name, char **argv, LinkList assigns, Options ops, int func)
 	 * to be exported properly.
 	 *
-	 * This may create the array with PM_DECLAREDNULL.
+	 * This may create the array with PM_DEFAULTED.
 	 */
 	asg2.name = asg->name;